@@ -4,7 +4,7 @@
  * Copyright (C) 2014, 2015 Hans-Peter Deifel <hpdeifel@gmx.de>
  * Copyright (C) 2015, Tamas Szekeres <szekerest@gmail.com>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
- * Copyright (C) 2018, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2018, 2020, 2021, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2018 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
  * Copyright (C) 2018, 2020, Adam Reichold <adam.reichold@t-online.de>
  *
@@ -44,22 +44,20 @@
 
 #include "config.h"
 
-namespace
-{
+namespace {
 
 struct MiniIconv
 {
-    MiniIconv(const char *to_code, const char *from_code)
-        : i_(iconv_open(to_code, from_code))
-    {}
+    MiniIconv(const char *to_code, const char *from_code) : i_(iconv_open(to_code, from_code)) { }
     ~MiniIconv()
-    { if (is_valid()) iconv_close(i_); }
+    {
+        if (is_valid())
+            iconv_close(i_);
+    }
     MiniIconv(const MiniIconv &) = delete;
-    MiniIconv& operator=(const MiniIconv &) = delete;
-    bool is_valid() const
-    { return i_ != (iconv_t)-1; }
-    operator iconv_t() const
-    { return i_; }
+    MiniIconv &operator=(const MiniIconv &) = delete;
+    bool is_valid() const { return i_ != (iconv_t)-1; }
+    explicit operator iconv_t() const { return i_; }
     iconv_t i_;
 };
 
@@ -203,28 +201,15 @@ using namespace poppler;
  The case sensitivity.
 */
 
+noncopyable::noncopyable() { }
 
-noncopyable::noncopyable()
-{
-}
+noncopyable::~noncopyable() { }
 
-noncopyable::~noncopyable()
-{
-}
+ustring::ustring() { }
 
+ustring::ustring(size_type len, value_type ch) : std::basic_string<value_type>(len, ch) { }
 
-ustring::ustring()
-{
-}
-
-ustring::ustring(size_type len, value_type ch)
-    : std::basic_string<value_type>(len, ch)
-{
-}
-
-ustring::~ustring()
-{
-}
+ustring::~ustring() { }
 
 byte_array ustring::to_utf8() const
 {
@@ -241,17 +226,17 @@ byte_array ustring::to_utf8() const
         return byte_array();
     }
     const value_type *me_data = data();
-    byte_array str(size()*sizeof(value_type));
+    byte_array str(size() * sizeof(value_type));
     char *str_data = &str[0];
-    size_t me_len_char = size()*sizeof(value_type);
+    size_t me_len_char = size() * sizeof(value_type);
     size_t str_len_left = str.size();
-    size_t ir = iconv(ic, (ICONV_CONST char **)&me_data, &me_len_char, &str_data, &str_len_left);
+    size_t ir = iconv(static_cast<iconv_t>(ic), (ICONV_CONST char **)&me_data, &me_len_char, &str_data, &str_len_left);
     if ((ir == (size_t)-1) && (errno == E2BIG)) {
         const size_t delta = str_data - &str[0];
         str_len_left += str.size();
         str.resize(str.size() * 2);
         str_data = &str[delta];
-        ir = iconv(ic, (ICONV_CONST char **)&me_data, &me_len_char, &str_data, &str_len_left);
+        ir = iconv(static_cast<iconv_t>(ic), (ICONV_CONST char **)&me_data, &me_len_char, &str_data, &str_len_left);
         if (ir == (size_t)-1) {
             return byte_array();
         }
@@ -294,23 +279,23 @@ ustring ustring::from_utf8(const char *str, int len)
     }
 
     // +1, because iconv inserts byte order marks
-    ustring ret(len+1, 0);
+    ustring ret(len + 1, 0);
     char *ret_data = reinterpret_cast<char *>(&ret[0]);
     char *str_data = const_cast<char *>(str);
     size_t str_len_char = len;
     size_t ret_len_left = ret.size() * sizeof(ustring::value_type);
-    size_t ir = iconv(ic, (ICONV_CONST char **)&str_data, &str_len_char, &ret_data, &ret_len_left);
+    size_t ir = iconv(static_cast<iconv_t>(ic), (ICONV_CONST char **)&str_data, &str_len_char, &ret_data, &ret_len_left);
     if ((ir == (size_t)-1) && (errno == E2BIG)) {
         const size_t delta = ret_data - reinterpret_cast<char *>(&ret[0]);
-        ret_len_left += ret.size()*sizeof(ustring::value_type);
+        ret_len_left += ret.size() * sizeof(ustring::value_type);
         ret.resize(ret.size() * 2);
         ret_data = reinterpret_cast<char *>(&ret[0]) + delta;
-        ir = iconv(ic, (ICONV_CONST char **)&str_data, &str_len_char, &ret_data, &ret_len_left);
+        ir = iconv(static_cast<iconv_t>(ic), (ICONV_CONST char **)&str_data, &str_len_char, &ret_data, &ret_len_left);
         if (ir == (size_t)-1) {
             return ustring();
         }
     }
-    ret.resize(ret.size() - ret_len_left/sizeof(ustring::value_type));
+    ret.resize(ret.size() - ret_len_left / sizeof(ustring::value_type));
 
     return ret;
 }
@@ -324,12 +309,12 @@ ustring ustring::from_latin1(const std::string &str)
     const char *c = str.data();
     ustring ret(l, 0);
     for (size_type i = 0; i < l; ++i) {
-        ret[i] = *c++;
+        ret[i] = static_cast<unsigned char>(*c);
+        c++;
     }
     return ret;
 }
 
-
 /**
  Converts a string representing a PDF date to a value compatible with time_t.
  */
@@ -339,15 +324,14 @@ time_type poppler::convert_date(const std::string &date)
     return dateStringToTime(&gooDateStr);
 }
 
-std::ostream& poppler::operator<<(std::ostream& stream, const byte_array &array)
+std::ostream &poppler::operator<<(std::ostream &stream, const byte_array &array)
 {
     stream << "[";
     const std::ios_base::fmtflags f = stream.flags();
     std::hex(stream);
     const char *data = &array[0];
     const byte_array::size_type out_len = std::min<byte_array::size_type>(array.size(), 50);
-    for (byte_array::size_type i = 0; i < out_len; ++i)
-    {
+    for (byte_array::size_type i = 0; i < out_len; ++i) {
         if (i != 0) {
             stream << " ";
         }
