@@ -43,14 +43,7 @@
 
 using namespace poppler;
 
-page_private::page_private(document_private *_doc, int _index)
-    : doc(_doc)
-    , page(doc->doc->getCatalog()->getPage(_index + 1))
-    , index(_index)
-    , transition(nullptr)
-    , font_info_cache_initialized(false)
-{
-}
+page_private::page_private(document_private *_doc, int _index) : doc(_doc), page(doc->doc->getCatalog()->getPage(_index + 1)), index(_index), transition(nullptr), font_info_cache_initialized(false) { }
 
 page_private::~page_private()
 {
@@ -60,12 +53,12 @@ page_private::~page_private()
 void page_private::init_font_info_cache()
 {
     if (font_info_cache_initialized)
-	return;
+        return;
 
     poppler::font_iterator it(index, doc);
 
     if (it.has_next()) {
-	font_info_cache = it.next();
+        font_info_cache = it.next();
     }
 
     font_info_cache_initialized = true;
@@ -96,11 +89,7 @@ void page_private::init_font_info_cache()
  A layout of the text of a page.
 */
 
-
-page::page(document_private *doc, int index)
-    : d(new page_private(doc, index))
-{
-}
+page::page(document_private *doc, int index) : d(new page_private(doc, index)) { }
 
 /**
  Destructor.
@@ -198,7 +187,7 @@ ustring page::label() const
 
  \returns the transition effect for the switch to the next page, if any
  */
-page_transition* page::transition() const
+page_transition *page::transition() const
 {
     if (!d->transition) {
         Object o = d->page->getTrans();
@@ -219,10 +208,14 @@ page_transition* page::transition() const
  \param case_sensitivity whether search in a case sensitive way
  \param rotation the rotation assumed for the page
  */
-bool page::search(const ustring &text, rectf &r, search_direction_enum direction,
-                  case_sensitivity_enum case_sensitivity, rotation_enum rotation) const
+bool page::search(const ustring &text, rectf &r, search_direction_enum direction, case_sensitivity_enum case_sensitivity, rotation_enum rotation) const
 {
     const size_t len = text.length();
+
+    if (len == 0) {
+        return false;
+    }
+
     std::vector<Unicode> u(len);
     for (size_t i = 0; i < len; ++i) {
         u[i] = text[i];
@@ -243,19 +236,13 @@ bool page::search(const ustring &text, rectf &r, search_direction_enum direction
 
     switch (direction) {
     case search_from_top:
-        found = text_page->findText(&u[0], len,
-                    true, true, false, false, sCase, false, false,
-                    &rect_left, &rect_top, &rect_right, &rect_bottom);
+        found = text_page->findText(&u[0], len, true, true, false, false, sCase, false, false, &rect_left, &rect_top, &rect_right, &rect_bottom);
         break;
     case search_next_result:
-        found = text_page->findText(&u[0], len,
-                    false, true, true, false, sCase, false, false,
-                    &rect_left, &rect_top, &rect_right, &rect_bottom);
+        found = text_page->findText(&u[0], len, false, true, true, false, sCase, false, false, &rect_left, &rect_top, &rect_right, &rect_bottom);
         break;
     case search_previous_result:
-        found = text_page->findText(&u[0], len,
-                    false, true, true, false, sCase, true, false,
-                    &rect_left, &rect_top, &rect_right, &rect_bottom);
+        found = text_page->findText(&u[0], len, false, true, true, false, sCase, true, false, &rect_left, &rect_top, &rect_right, &rect_bottom);
         break;
     }
 
@@ -281,8 +268,9 @@ ustring page::text(const rectf &r) const
     return text(r, physical_layout);
 }
 
-static void appendToGooString(void *stream, const char *text, int len) {
-  ((GooString *) stream)->append(text, len);
+static void appendToGooString(void *stream, const char *text, int len)
+{
+    ((GooString *)stream)->append(text, len);
 }
 
 /**
@@ -305,8 +293,7 @@ ustring page::text(const rectf &r, text_layout_enum layout_mode) const
     if (r.is_empty()) {
         d->doc->doc->displayPage(&td, d->index + 1, 72, 72, 0, false, true, false);
     } else {
-        d->doc->doc->displayPageSlice(&td, d->index + 1, 72, 72, 0, false, true, false,
-				      r.left(), r.top(), r.width(), r.height());
+        d->doc->doc->displayPageSlice(&td, d->index + 1, 72, 72, 0, false, true, false, r.left(), r.top(), r.width(), r.height());
     }
     return ustring::from_utf8(out->c_str());
 }
@@ -323,12 +310,10 @@ text_box_data::~text_box_data() = default;
 
 text_box::~text_box() = default;
 
-text_box& text_box::operator=(text_box&& a) noexcept = default;
-text_box::text_box(text_box&& a) noexcept = default;
+text_box &text_box::operator=(text_box &&a) noexcept = default;
+text_box::text_box(text_box &&a) noexcept = default;
 
-text_box::text_box(text_box_data *data) : m_data{data}
-{
-}
+text_box::text_box(text_box_data *data) : m_data { data } { }
 
 ustring text_box::text() const
 {
@@ -392,15 +377,14 @@ std::string text_box::get_font_name(int i) const
 
 std::vector<text_box> page::text_list(int opt_flag) const
 {
-    std::vector<text_box>  output_list;
+    std::vector<text_box> output_list;
 
     /* config values are same with Qt5 Page::TextList() */
-    auto output_dev = std::make_unique<TextOutputDev>(
-	nullptr, /* char* fileName */
-	false,   /* bool physLayoutA */
-	0,       /* double fixedPitchA */
-	false,   /* bool rawOrderA */
-	false    /* bool append */
+    auto output_dev = std::make_unique<TextOutputDev>(nullptr, /* char* fileName */
+                                                      false, /* bool physLayoutA */
+                                                      0, /* double fixedPitchA */
+                                                      false, /* bool rawOrderA */
+                                                      false /* bool append */
     );
 
     /*
@@ -408,60 +392,52 @@ std::vector<text_box> page::text_list(int opt_flag) const
      * but rotation is fixed to zero.
      * Few people use non-zero values.
      */
-    d->doc->doc->displayPageSlice(output_dev.get(),
-                                  d->index + 1,           /* page */
-                                  72, 72, 0,              /* hDPI, vDPI, rot */
-                                  false, false, false,    /* useMediaBox, crop, printing */
-                                  -1, -1, -1, -1,         /* sliceX, sliceY, sliceW, sliceH */
-                                  nullptr, nullptr,       /* abortCheckCbk(), abortCheckCbkData */
-                                  nullptr, nullptr,       /* annotDisplayDecideCbk(), annotDisplayDecideCbkData */
-                                  true);                  /* copyXRef */
+    d->doc->doc->displayPageSlice(output_dev.get(), d->index + 1, /* page */
+                                  72, 72, 0, /* hDPI, vDPI, rot */
+                                  false, false, false, /* useMediaBox, crop, printing */
+                                  -1, -1, -1, -1, /* sliceX, sliceY, sliceW, sliceH */
+                                  nullptr, nullptr, /* abortCheckCbk(), abortCheckCbkData */
+                                  nullptr, nullptr, /* annotDisplayDecideCbk(), annotDisplayDecideCbkData */
+                                  true); /* copyXRef */
 
-    if (std::unique_ptr< TextWordList > word_list{output_dev->makeWordList()}) {
+    if (std::unique_ptr<TextWordList> word_list { output_dev->makeWordList() }) {
 
         output_list.reserve(word_list->getLength());
-        for (int i = 0; i < word_list->getLength(); i ++) {
+        for (int i = 0; i < word_list->getLength(); i++) {
             TextWord *word = word_list->get(i);
 
-            std::unique_ptr<GooString> gooWord{word->getText()};
+            std::unique_ptr<GooString> gooWord { word->getText() };
             ustring ustr = ustring::from_utf8(gooWord->c_str());
 
             double xMin, yMin, xMax, yMax;
             word->getBBox(&xMin, &yMin, &xMax, &yMax);
 
-            text_box tb{new text_box_data{
-                ustr,
-                {xMin, yMin, xMax-xMin, yMax-yMin},
-                word->getRotation(),
-                {},
-                word->hasSpaceAfter() == true,
-                nullptr
-            }};
+            text_box tb { new text_box_data { ustr, { xMin, yMin, xMax - xMin, yMax - yMin }, word->getRotation(), {}, word->hasSpaceAfter() == true, nullptr } };
 
             std::unique_ptr<text_box_font_info_data> tb_font_info = nullptr;
             if (opt_flag & page::text_list_include_font) {
                 d->init_font_info_cache();
 
-                std::unique_ptr<text_box_font_info_data> tb_font{new text_box_font_info_data{
-                    word->getFontSize(), // double font_size
-                    {},                  // std::vector<text_box::writing_mode> wmodes;
-                    d->font_info_cache,  // std::vector<font_info> font_info_cache;
-                    {}                   // std::vector<int> glyph_to_cache_index;
-                }};
+                std::unique_ptr<text_box_font_info_data> tb_font { new text_box_font_info_data {
+                        word->getFontSize(), // double font_size
+                        {}, // std::vector<text_box::writing_mode> wmodes;
+                        d->font_info_cache, // std::vector<font_info> font_info_cache;
+                        {} // std::vector<int> glyph_to_cache_index;
+                } };
 
                 tb_font_info = std::move(tb_font);
             };
 
             tb.m_data->char_bboxes.reserve(word->getLength());
-            for (int j = 0; j < word->getLength(); j ++) {
+            for (int j = 0; j < word->getLength(); j++) {
                 word->getCharBBox(j, &xMin, &yMin, &xMax, &yMax);
-                tb.m_data->char_bboxes.emplace_back(xMin, yMin, xMax-xMin, yMax-yMin);
+                tb.m_data->char_bboxes.emplace_back(xMin, yMin, xMax - xMin, yMax - yMin);
             }
 
             if (tb_font_info && d->font_info_cache_initialized) {
                 tb_font_info->glyph_to_cache_index.reserve(word->getLength());
                 for (int j = 0; j < word->getLength(); j++) {
-                    const TextFontInfo* cur_text_font_info = word->getFontInfo(j);
+                    const TextFontInfo *cur_text_font_info = word->getFontInfo(j);
 
                     // filter-out the invalid WMode value here.
                     switch (cur_text_font_info->getWMode()) {
