@@ -18,7 +18,7 @@
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2006 Krzysztof Kowalczyk <kkowalczyk@gmail.com>
 // Copyright (C) 2007 Jeff Muizelaar <jeff@infidigm.net>
-// Copyright (C) 2008-2011, 2016-2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008-2011, 2016-2018, 2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2011 Kenji Uno <ku@digitaldolphins.jp>
 // Copyright (C) 2012, 2013 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
@@ -418,8 +418,13 @@ GooString *GooString::appendfv(const char *fmt, va_list argList)
                     reverseAlign = !reverseAlign;
                     break;
                 case fmtGooString:
-                    str = arg.gs->c_str();
-                    len = arg.gs->getLength();
+                    if (arg.gs) {
+                        str = arg.gs->c_str();
+                        len = arg.gs->getLength();
+                    } else {
+                        str = "(null)";
+                        len = 6;
+                    }
                     reverseAlign = !reverseAlign;
                     break;
                 case fmtSpace:
