@@ -16,7 +16,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2009, 2011, 2012, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2011, 2012, 2017, 2018, 2021, 2022 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Kovid Goyal <kovid@kovidgoyal.net>
 // Copyright (C) 2013 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
@@ -37,51 +37,59 @@
 
 #include "poppler-config.h"
 
+#include <memory>
+
 class GooString;
 
+#if defined(_WIN32)
+#    include <windows.h>
+#else
+#    include <dirent.h>
+#endif
+
 //------------------------------------------------------------------------
 // GDir and GDirEntry
 //------------------------------------------------------------------------
 
-class GDirEntry {
+class GDirEntry
+{
 public:
+    GDirEntry(const char *dirPath, const char *nameA, bool doStat);
+    ~GDirEntry();
 
-  GDirEntry(const char *dirPath, const char *nameA, bool doStat);
-  ~GDirEntry();
+    GDirEntry(const GDirEntry &other) = delete;
+    GDirEntry &operator=(const GDirEntry &other) = delete;
 
-  GDirEntry(const GDirEntry &other) = delete;
-  GDirEntry& operator=(const GDirEntry &other) = delete;
-
-  const GooString *getName() const { return name; }
-  const GooString *getFullPath() const { return fullPath; }
-  bool isDir() const { return dir; }
+    const GooString *getName() const { return name; }
+    const GooString *getFullPath() const { return fullPath; }
+    bool isDir() const { return dir; }
 
 private:
-  GooString *name;		// dir/file name
-  GooString *fullPath;
-  bool dir;			// is it a directory?
+    GooString *name; // dir/file name
+    GooString *fullPath;
+    bool dir; // is it a directory?
 };
 
-class GDir {
+class GDir
+{
 public:
+    explicit GDir(const char *name, bool doStatA = true);
+    ~GDir();
 
-  GDir(const char *name, bool doStatA = true);
-  ~GDir();
+    GDir(const GDir &other) = delete;
+    GDir &operator=(const GDir &other) = delete;
 
-  GDir(const GDir &other) = delete;
-  GDir& operator=(const GDir &other) = delete;
-
-  GDirEntry *getNextEntry();
-  void rewind();
+    std::unique_ptr<GDirEntry> getNextEntry();
+    void rewind();
 
 private:
-  GooString *path;		// directory path
-  bool doStat;			// call stat() for each entry?
+    GooString *path; // directory path
+    bool doStat; // call stat() for each entry?
 #if defined(_WIN32)
-  WIN32_FIND_DATAA ffd;
-  HANDLE hnd;
+    WIN32_FIND_DATAA ffd;
+    HANDLE hnd;
 #else
-  DIR *dir;			// the DIR structure from opendir()
+    DIR *dir; // the DIR structure from opendir()
 #endif
 };
 
