@@ -5,7 +5,7 @@
 //---------------------------------------------------------------------------------
 // Hugo Mercier <hmercier31[at]gmail.com> (c) 2008
 // Carlos Garcia Campos <carlosgc@gnome.org> (c) 2010
-// Albert Astals Cid <aacid@kde.org> (C) 2017, 2018
+// Albert Astals Cid <aacid@kde.org> (C) 2017, 2018, 2021
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -118,10 +118,10 @@ struct MediaParameters
     MediaWindowParameters windowParams;
 };
 
-class MediaRendition
+class POPPLER_PRIVATE_EXPORT MediaRendition
 {
 public:
-    MediaRendition(Object *obj);
+    explicit MediaRendition(Object *obj);
     MediaRendition(const MediaRendition &other);
     ~MediaRendition();
     MediaRendition &operator=(const MediaRendition &) = delete;
