@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008-2009, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013, Fabio D'Urso <fabiodurso@hotmail.it>
- * Copyright (C) 2019, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2019, 2022, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,7 @@ NavigationToolBar::NavigationToolBar(QWidget *parent) : QToolBar(parent)
     m_firstAct = addAction(tr("First"), this, SLOT(slotGoFirst()));
     m_prevAct = addAction(tr("Previous"), this, SLOT(slotGoPrev()));
     m_pageCombo = new QComboBox(this);
-    // TODO replace with qOverload once we start requiring Qt 5.7
-    connect(m_pageCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &NavigationToolBar::slotComboActivated);
+    connect(m_pageCombo, qOverload<int>(&QComboBox::activated), this, &NavigationToolBar::slotComboActivated);
     addWidget(m_pageCombo);
     m_nextAct = addAction(tr("Next"), this, SLOT(slotGoNext()));
     m_lastAct = addAction(tr("Last"), this, SLOT(slotGoLast()));
@@ -53,8 +52,7 @@ NavigationToolBar::NavigationToolBar(QWidget *parent) : QToolBar(parent)
     m_zoomCombo->addItem(tr("300%"));
     m_zoomCombo->addItem(tr("400%"));
     m_zoomCombo->setCurrentIndex(6); // "100%"
-    // TODO replace with qOverload once we start requiring Qt 5.7
-    connect(m_zoomCombo, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::currentIndexChanged), this, &NavigationToolBar::slotZoomComboChanged);
+    connect(m_zoomCombo, qOverload<const QString &>(&QComboBox::currentIndexChanged), this, &NavigationToolBar::slotZoomComboChanged);
     addWidget(m_zoomCombo);
 
     m_rotationCombo = new QComboBox(this);
@@ -63,8 +61,7 @@ NavigationToolBar::NavigationToolBar(QWidget *parent) : QToolBar(parent)
     m_rotationCombo->addItem(tr("90\302\260"));
     m_rotationCombo->addItem(tr("180\302\260"));
     m_rotationCombo->addItem(tr("270\302\260"));
-    // TODO replace with qOverload once we start requiring Qt 5.7
-    connect(m_rotationCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NavigationToolBar::slotRotationComboChanged);
+    connect(m_rotationCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &NavigationToolBar::slotRotationComboChanged);
     addWidget(m_rotationCombo);
 
     documentClosed();
