@@ -2,6 +2,7 @@
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
  * Copyright (C) 2021, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2021, Even Rouault <even.rouault@spatialys.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ public:
     void close() override;
     Goffset getPos() override;
     void put(char c) override;
-    void printf(const char *format, ...) override;
+    void printf(const char *format, ...) override GCC_PRINTF_FORMAT(2, 3);
 
 private:
     QIODevice *m_device;
