@@ -2,6 +2,7 @@
  * Copyright (C) 2008-2009, Pino Toscano <pino@kde.org>
  * Copyright (C) 2013, Fabio D'Urso <fabiodurso@hotmail.it>
  * Copyright (C) 2017, 2020, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2021, Oliver Sander <oliver.sander@tu-dresden.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +48,7 @@ void PageView::documentClosed()
 
 void PageView::pageChanged(int page)
 {
-    Poppler::Page *popplerPage = document()->page(page);
+    std::unique_ptr<Poppler::Page> popplerPage = document()->page(page);
 
     if (!popplerPage) {
         qDebug() << "Page" << page << "is malformed";
@@ -74,7 +75,6 @@ void PageView::pageChanged(int page)
         m_imageLabel->resize(0, 0);
         m_imageLabel->setPixmap(QPixmap());
     }
-    delete popplerPage;
 }
 
 void PageView::slotZoomChanged(qreal value)
