@@ -261,8 +261,8 @@ QString Document::info(const QString &type) const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoStringEntry(type.toLatin1().constData()));
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoStringEntry(type.toLatin1().constData()));
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setInfo(const QString &key, const QString &val)
@@ -282,8 +282,8 @@ QString Document::title() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoTitle());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoTitle());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setTitle(const QString &val)
@@ -302,8 +302,8 @@ QString Document::author() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoAuthor());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoAuthor());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setAuthor(const QString &val)
@@ -322,8 +322,8 @@ QString Document::subject() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoSubject());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoSubject());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setSubject(const QString &val)
@@ -342,8 +342,8 @@ QString Document::keywords() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoKeywords());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoKeywords());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setKeywords(const QString &val)
@@ -362,8 +362,8 @@ QString Document::creator() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoCreator());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoCreator());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setCreator(const QString &val)
@@ -382,8 +382,8 @@ QString Document::producer() const
         return QString();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoProducer());
-    return UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoProducer());
+    return UnicodeParsedString(goo.get());
 }
 
 bool Document::setProducer(const QString &val)
@@ -436,8 +436,8 @@ QDateTime Document::date(const QString &type) const
         return QDateTime();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoStringEntry(type.toLatin1().constData()));
-    QString str = UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoStringEntry(type.toLatin1().constData()));
+    QString str = UnicodeParsedString(goo.get());
     return Poppler::convertDate(str.toLatin1().constData());
 }
 
@@ -457,8 +457,8 @@ QDateTime Document::creationDate() const
         return QDateTime();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoCreatDate());
-    QString str = UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoCreatDate());
+    QString str = UnicodeParsedString(goo.get());
     return Poppler::convertDate(str.toLatin1().constData());
 }
 
@@ -478,8 +478,8 @@ QDateTime Document::modificationDate() const
         return QDateTime();
     }
 
-    QScopedPointer<GooString> goo(m_doc->doc->getDocInfoModDate());
-    QString str = UnicodeParsedString(goo.data());
+    std::unique_ptr<GooString> goo(m_doc->doc->getDocInfoModDate());
+    QString str = UnicodeParsedString(goo.get());
     return Poppler::convertDate(str.toLatin1().constData());
 }
 
@@ -714,10 +714,9 @@ QString Document::metadata() const
     QString result;
     Catalog *catalog = m_doc->doc->getCatalog();
     if (catalog && catalog->isOk()) {
-        GooString *s = catalog->readMetadata();
+        std::unique_ptr<GooString> s = catalog->readMetadata();
         if (s)
-            result = UnicodeParsedString(s);
-        delete s;
+            result = UnicodeParsedString(s.get());
     }
     return result;
 }
