@@ -1,5 +1,5 @@
 /* poppler-embeddedfile-private.h: Qt interface to poppler
- * Copyright (C) 2005, 2008, 2009, 2012, 2018, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005, 2008, 2009, 2012, 2018, 2021, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
  * Copyright (C) 2008, 2011, Pino Toscano <pino@kde.org>
  *
@@ -28,7 +28,7 @@ namespace Poppler {
 class EmbeddedFileData
 {
 public:
-    EmbeddedFileData(FileSpec *fs);
+    explicit EmbeddedFileData(FileSpec *fs);
     ~EmbeddedFileData();
 
     EmbeddedFileData(const EmbeddedFileData &) = delete;
