@@ -13,7 +13,7 @@
 //
 // Copyright (C) 2007 Ilmari Heikkinen <ilmari.heikkinen@gmail.com>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
-// Copyright (C) 2009, 2012, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2012, 2018, 2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
 // Copyright (C) 2010, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010 Harry Roberts <harry.roberts@midnight-labs.org>
@@ -51,23 +51,26 @@ public:
     // color mode <modeA>.  Rows will be padded out to a multiple of
     // <rowPad> bytes.  If <topDown> is false, the bitmap will be stored
     // upside-down, i.e., with the last row first in memory.
-    SplashBitmap(int widthA, int heightA, int rowPad, SplashColorMode modeA, bool alphaA, bool topDown = true, std::vector<GfxSeparationColorSpace *> *separationList = nullptr);
-    static SplashBitmap *copy(SplashBitmap *src);
+    SplashBitmap(int widthA, int heightA, int rowPad, SplashColorMode modeA, bool alphaA, bool topDown = true, const std::vector<GfxSeparationColorSpace *> *separationList = nullptr);
+    static SplashBitmap *copy(const SplashBitmap *src);
 
     ~SplashBitmap();
 
     SplashBitmap(const SplashBitmap &) = delete;
     SplashBitmap &operator=(const SplashBitmap &) = delete;
 
-    int getWidth() { return width; }
-    int getHeight() { return height; }
-    int getRowSize() { return rowSize; }
-    int getAlphaRowSize() { return width; }
-    int getRowPad() { return rowPad; }
-    SplashColorMode getMode() { return mode; }
+    int getWidth() const { return width; }
+    int getHeight() const { return height; }
+    int getRowSize() const { return rowSize; }
+    int getAlphaRowSize() const { return width; }
+    int getRowPad() const { return rowPad; }
+    SplashColorMode getMode() const { return mode; }
     SplashColorPtr getDataPtr() { return data; }
     unsigned char *getAlphaPtr() { return alpha; }
     std::vector<GfxSeparationColorSpace *> *getSeparationList() { return separationList; }
+    SplashColorConstPtr getDataPtr() const { return data; }
+    const unsigned char *getAlphaPtr() const { return alpha; }
+    const std::vector<GfxSeparationColorSpace *> *getSeparationList() const { return separationList; }
 
     SplashError writePNMFile(char *fileName);
     SplashError writePNMFile(FILE *f);
