@@ -12,7 +12,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
-// Copyright (C) 2008, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
@@ -23,10 +23,7 @@
 #include <config.h>
 
 #include <cstdio>
-// TODO remove here and below once we depend on a new enough gcc in our CI
-#if __has_include(<filesystem>)
-#    include <filesystem>
-#else
+#ifdef HAVE_UNISTD_H
 #    include <unistd.h>
 #endif
 #include "goo/gmem.h"
@@ -80,15 +77,8 @@ SplashFontSrc::~SplashFontSrc()
 {
     if (deleteSrc) {
         if (isFile) {
-            if (fileName) {
-#if __has_include(<filesystem>)
-                // We don't care about any error, but we don't want it to throw
-                std::error_code error_code;
-                std::filesystem::remove(fileName->c_str(), error_code);
-#else
+            if (fileName)
                 unlink(fileName->c_str());
-#endif
-            }
         } else {
             if (buf)
                 gfree(buf);
@@ -110,7 +100,7 @@ void SplashFontSrc::unref()
         delete this;
 }
 
-void SplashFontSrc::setFile(GooString *file, bool del)
+void SplashFontSrc::setFile(const GooString *file, bool del)
 {
     isFile = true;
     fileName = file->copy();
