@@ -42,7 +42,7 @@ public:
     SplashFontSrc(const SplashFontSrc &) = delete;
     SplashFontSrc &operator=(const SplashFontSrc &) = delete;
 
-    void setFile(GooString *file, bool del);
+    void setFile(const GooString *file, bool del);
     void setFile(const char *file, bool del);
     void setBuf(char *bufA, int buflenA, bool del);
 
