@@ -21,20 +21,20 @@
 #ifndef SPLASHFONTFILEID_H
 #define SPLASHFONTFILEID_H
 
-#include "goo/gtypes.h"
+#include "poppler_private_export.h"
 
 //------------------------------------------------------------------------
 // SplashFontFileID
 //------------------------------------------------------------------------
 
-class SplashFontFileID {
+class POPPLER_PRIVATE_EXPORT SplashFontFileID
+{
 public:
-
-  SplashFontFileID();
-  virtual ~SplashFontFileID();
-  SplashFontFileID(const SplashFontFileID &) = delete;
-  SplashFontFileID& operator=(const SplashFontFileID &) = delete;
-  virtual bool matches(SplashFontFileID *id) = 0;
+    SplashFontFileID();
+    virtual ~SplashFontFileID();
+    SplashFontFileID(const SplashFontFileID &) = delete;
+    SplashFontFileID &operator=(const SplashFontFileID &) = delete;
+    virtual bool matches(SplashFontFileID *id) = 0;
 };
 
 #endif
