@@ -16,6 +16,7 @@
 // Copyright 2019 Nelson Efrain A. Cruz <neac03@gmail.com>
 // Copyright 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
 // Copyright 2021 Theofilos Intzoglou <int.teo@gmail.com>
+// Copyright 2022 Felix Jung <fxjung@posteo.de>
 //
 //========================================================================
 
@@ -43,7 +44,9 @@
 #include "Win32Console.h"
 #include "numberofcharacters.h"
 #include "UTF.h"
-#include <libgen.h>
+#if __has_include(<libgen.h>)
+#    include <libgen.h>
+#endif
 
 static const char *getReadableSigState(SignatureValidationStatus sig_vs)
 {
@@ -341,7 +344,7 @@ int main(int argc, char *argv[])
 
         // We don't provide a way to customize the UI from pdfsig for now
         const bool success = doc->sign(argv[2], certNickname, pw, newSignatureFieldName.copy(), /*page*/ 1,
-                                       /*rect */ { 0, 0, 0, 0 }, /*signatureText*/ {}, /*signatureTextLeft*/ {}, /*fontSize */ 0,
+                                       /*rect */ { 0, 0, 0, 0 }, /*signatureText*/ {}, /*signatureTextLeft*/ {}, /*fontSize */ 0, /*leftFontSize*/ 0,
                                        /*fontColor*/ {}, /*borderWidth*/ 0, /*borderColor*/ {}, /*backgroundColor*/ {}, rs.get(), /* location */ nullptr, /* image path */ "", ownerPW.get(), userPW.get());
         return success ? 0 : 3;
     }
@@ -418,8 +421,15 @@ int main(int argc, char *argv[])
     }
 
     for (unsigned int i = 0; i < sigCount; i++) {
-        const SignatureInfo *sig_info = signatures.at(i)->validateSignature(!dontVerifyCert, false, -1 /* now */, !noOCSPRevocationCheck, useAIACertFetch);
+        FormFieldSignature *ffs = signatures.at(i);
         printf("Signature #%u:\n", i + 1);
+
+        if (ffs->getSignatureType() == unsigned_signature_field) {
+            printf("  The signature form field is not signed.\n");
+            continue;
+        }
+
+        const SignatureInfo *sig_info = ffs->validateSignature(!dontVerifyCert, false, -1 /* now */, !noOCSPRevocationCheck, useAIACertFetch);
         printf("  - Signer Certificate Common Name: %s\n", sig_info->getSignerName());
         printf("  - Signer full Distinguished Name: %s\n", sig_info->getSubjectDN());
         printf("  - Signing Time: %s\n", time_str = getReadableTime(sig_info->getSigningTime()));
@@ -450,7 +460,7 @@ int main(int argc, char *argv[])
             printf("unknown\n");
         }
         printf("  - Signature Type: ");
-        switch (signatures.at(i)->getSignatureType()) {
+        switch (ffs->getSignatureType()) {
         case adbe_pkcs7_sha1:
             printf("adbe.pkcs7.sha1\n");
             break;
@@ -463,7 +473,7 @@ int main(int argc, char *argv[])
         default:
             printf("unknown\n");
         }
-        std::vector<Goffset> ranges = signatures.at(i)->getSignedRangeBounds();
+        const std::vector<Goffset> ranges = ffs->getSignedRangeBounds();
         if (ranges.size() == 4) {
             printf("  - Signed Ranges: [%lld - %lld], [%lld - %lld]\n", ranges[0], ranges[1], ranges[2], ranges[3]);
             Goffset checked_file_size;
