@@ -38,6 +38,7 @@
 // Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
 // Copyright (C) 2020 Salvo Miosi <salvo.ilmiosi@gmail.com>
 // Copyright (C) 2021 Peter Williams <peter@newton.cx>
+// Copyright (C) 2021 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -648,12 +649,20 @@ static void renderPage(PDFDoc *doc, CairoOutputDev *cairoOut, int pg, double pag
     cairo_t *cr;
     cairo_status_t status;
     cairo_matrix_t m;
+    cairo_font_options_t *font_options;
 
     cr = cairo_create(surface);
 
+    cairo_set_antialias(cr, antialiasEnum);
+
+    font_options = cairo_font_options_create();
+    cairo_get_font_options(cr, font_options);
+    cairo_font_options_set_antialias(font_options, antialiasEnum);
+    cairo_set_font_options(cr, font_options);
+    cairo_font_options_destroy(font_options);
+
     cairoOut->setCairo(cr);
     cairoOut->setPrinting(printing);
-    cairoOut->setAntialias(antialiasEnum);
 
     cairo_save(cr);
     if (ps && output_w > output_h) {
